A small encrypted persistent store for named application credentials.
Structs
- Credential
Vault - An in-memory set of named credentials backed by one encrypted file.
- Error
- A sanitized credential-vault failure.
Enums
- Error
Kind - Stable high-level classification for a vault operation failure.
Traits
- Expose
Secret - Expose a reference to an inner secret
Type Aliases
- Result
- Secret
String - Secret string type.