CredentialVault

Struct CredentialVault 

pub struct CredentialVault { /* private fields */ }
An in-memory set of named credentials backed by one encrypted file.

Implementations

Source

impl CredentialVault

pub fn empty() -> Self

Creates an empty in-memory vault without touching the filesystem.

pub fn unlock(path: &Path, passphrase: SecretString) -> Result<Self>

Decrypts and validates one complete vault file.

pub fn save(&self, path: &Path, passphrase: &SecretString) -> Result<()>

Encrypts and durably replaces one complete vault file.

pub fn set(&mut self, name: &str, value: String) -> Result<()>

Inserts or replaces a named nonempty credential.

pub fn remove(&mut self, name: &str) -> Result<bool>

Removes a credential without exposing its value.

pub fn secret(&self, name: &str) -> Result<Option<SecretString>>

Returns a protected owned copy of one credential.

pub fn names(&self) -> impl Iterator<Item = &str>

Iterates credential names in lexical order without exposing values.